@@ -20,9 +20,26 @@ def extract_frames(
     extract_sound: bool = True,
     ffmpeg_path: Path = "ffmpeg",
 ):
+    """
+
+    :param file_path:
+    :type file_path:
+    :param frame_out_dir:
+    :type frame_out_dir:
+    :param audio_out_dir:
+    :type audio_out_dir:
+    :param rate:
+    :type rate:
+    :param frame_format:
+    :type frame_format:
+    :param extract_sound:
+    :type extract_sound:
+    :param ffmpeg_path:
+    :type ffmpeg_path:
+    """
     root_dir = file_path.parent
     if frame_out_dir is None:
-        frame_out_dir = ensure_existence(root_dir / "frames")
+        frame_out_dir = ensure_existence(root_dir / file_path.stem / "frames")
     if audio_out_dir is None:
         audio_out_dir = ensure_existence(frame_out_dir.parent / "audio")
 
@@ -40,7 +57,7 @@ def extract_frames(
                 "-y",
                 "-qscale:v",
                 "2",
-                str(frame_out_dir / f"{file_path.name}-%05d.{frame_format}"),
+                str(frame_out_dir / f"%d.{frame_format}"),
             ]
         )
         print(f"end extracting {file_path} frames")
@@ -56,7 +73,7 @@ def extract_frames(
                     "-acodec",
                     "copy",
                     "-y",
-                    str(audio_out_dir / f"{file_path.name}{AUDIO_FORMAT}"),
+                    str(audio_out_dir / f"track{AUDIO_FORMAT}"),
                 ]
             )
             print(f"end extracting {file_path} audio")
@@ -66,10 +83,15 @@ def extract_frames(
 
 if __name__ == "__main__":
     extract_frames(
-        Path.home() / "Downloads" / "brandt.mp4",
+        Path.home()
+        / "DataWin"
+        / "DeepFake"
+        / "Frontier"
+        / "Originals"
+        / "thomas_old_high_res.mp4",
         ffmpeg_path=Path.home()
-        / "Downloads"
-        / "ffmpeg-5.0-essentials_build"
+        / "OneDrive - Alexandra Instituttet"
+        / "Applications"
         / "ffmpeg-5.0-essentials_build"
         / "bin"
         / "ffmpeg.exe",
