@@ -14,6 +14,19 @@ def spilt_video(
     split_dir: Path = None,
     ffmpeg_path: Path = "ffmpeg",
 ) -> None:
+    """
+
+    :param video_path:
+    :type video_path:
+    :param start_time:
+    :type start_time:
+    :param stop_time:
+    :type stop_time:
+    :param split_dir:
+    :type split_dir:
+    :param ffmpeg_path:
+    :type ffmpeg_path:
+    """
     if split_dir is None:
         split_dir = ensure_existence(video_path.parent / "split")
 
@@ -50,10 +63,10 @@ def spilt_video(
 
 if __name__ == "__main__":
     spilt_video(
-        Path.home() / "Downloads" / "brandt.mp4",
+        Path.home() / "DataWin" / "DeepFake" / "Frontier" / "brandt.mp4",
         ffmpeg_path=Path.home()
-        / "Downloads"
-        / "ffmpeg-5.0-essentials_build"
+        / "OneDrive - Alexandra Instituttet"
+        / "Applications"
         / "ffmpeg-5.0-essentials_build"
         / "bin"
         / "ffmpeg.exe",
