@@ -28,7 +28,7 @@ import sh  # pip install sh
 from sorcery import assigned_names
 
 from draugr import PROJECT_NAME
-from draugr.os_utilities.linux_utilities.systemd_utilities.service_template import (
+from .service_template import (
     SERVICE_TEMPLATE,
 )
 from draugr.os_utilities.linux_utilities.user_utilities import make_user, remove_user
@@ -36,13 +36,13 @@ from warg import ContextWrapper
 
 
 class RunAsEnum(Enum):
-    """ """
+    """description"""
 
     user, app_user, root = assigned_names()
 
 
 def target_service_path(service_name, run_as: RunAsEnum = RunAsEnum.user):
-    """ """
+    """description"""
     if run_as == RunAsEnum.user:
         return Path.home() / ".config" / "systemd" / "user" / f"{service_name}.service"
     elif run_as == run_as.root:
@@ -99,6 +99,8 @@ def install_service(
 ) -> None:
     """
     Args:
+        :param template:
+        :type template:
         :param restart:
         :param service_entry_point_path:
         :param service_name:
