@@ -20,7 +20,7 @@ from warg import Number
 def minus_one_one_unnormalise(
     x: Union[Number, torch.Tensor, numpy.ndarray], low: float = 0, high: float = 1
 ) -> torch.tensor:
-    """ """
+    """description"""
     act_k = (high - low) / 2.0
     act_b = (high + low) / 2.0
     return act_k * x + act_b
@@ -29,7 +29,7 @@ def minus_one_one_unnormalise(
 def minus_one_one_normalise(
     x: Union[Number, torch.Tensor, numpy.ndarray], low: float = 0, high: float = 1
 ) -> torch.tensor:
-    """ """
+    """description"""
     act_k_inv = 2.0 / (high - low)
     act_b = (high + low) / 2.0
     return act_k_inv * (x - act_b)
