@@ -14,7 +14,7 @@ __all__ = ["plot_gradients_3d"]
 
 
 def plot_gradients_3d() -> pyplot.Figure:
-    """ """
+    """description"""
     fig = pyplot.figure()
     ax = fig.gca(projection="3d")
     x = numpy.arange(-5, 5, 0.25)
