@@ -46,6 +46,61 @@ class PilModesEnum(Enum):
     CMYK, F, HSV, I, L, LAB, P, RGB, RGBA, RGBX, YCbCr = assigned_names()
 
 
+"""
+1 (1-bit pixels, black and white, stored with one pixel per byte)
+
+L (8-bit pixels, black and white)
+
+P (8-bit pixels, mapped to any other mode using a color palette)
+
+RGB (3x8-bit pixels, true color)
+
+RGBA (4x8-bit pixels, true color with transparency mask)
+
+CMYK (4x8-bit pixels, color separation)
+
+YCbCr (3x8-bit pixels, color video format)
+
+Note that this refers to the JPEG, and not the ITU-R BT.2020, standard
+
+LAB (3x8-bit pixels, the L*a*b color space)
+
+HSV (3x8-bit pixels, Hue, Saturation, Value color space)
+
+I (32-bit signed integer pixels)
+
+F (32-bit floating point pixels)
+
+# Pillow also provides limited support for a few additional modes, including:
+
+LA (L with alpha)
+
+PA (P with alpha)
+
+RGBX (true color with padding)
+
+RGBa (true color with premultiplied alpha)
+
+La (L with premultiplied alpha)
+
+I;16 (16-bit unsigned integer pixels)
+
+I;16L (16-bit little endian unsigned integer pixels)
+
+I;16B (16-bit big endian unsigned integer pixels)
+
+I;16N (16-bit native endian unsigned integer pixels)
+
+BGR;15 (15-bit reversed true colour)
+
+BGR;16 (16-bit reversed true colour)
+
+BGR;24 (24-bit reversed true colour)
+
+BGR;32 (32-bit reversed true colour)
+"""
+
+
 def pil_image_to_byte_array(image: Image.Image, *, coding: str = "PNG") -> bytes:
     """
     PNG encoded by default
