@@ -43,7 +43,7 @@ def plot_median_labels(
     va: str = "center",  # bottom
     bbox: Tuple = semi_opaque_round_tight_bbox,
 ) -> None:
-    """ """
+    """description"""
     lines = ax.get_lines()
     # depending on fliers, toggle between 5 and 6 lines per box
     lines_per_box = 5 + int(has_fliers)
@@ -79,7 +79,7 @@ def plot_median_labels(
 
 
 def show_values_on_bars(axs: pyplot.Axes, h_v: str = "v", space: float = 0.4) -> None:
-    """ """
+    """description"""
 
     def _show_on_single_plot(ax):
         if h_v == "v":
